.. _gallery:

Gallery
=======

This gallery contains examples of the many things you can do with ``bewegung``.

A Simple Demo
-------------

.. youtube:: 5KldBStctRU

The `standard demo`_ of ``bewegung``, with different fonts and logo.

.. _standard demo: https://github.com/pleiszenburg/bewegung/blob/master/demo/demo.py

Earthquakes 1950-2020
---------------------

.. youtube:: mrcMhwgGWFw

This video shows a density distribution of 70 years of earthquakes, from 1950-01-01 to 2020-04-30, plotted "into" a rotating 3D sphere - the earth. It includes a total 3,809,839 events. The depth of the `hypocenters`_ is exaggerated by a factor of 6. Earthquake data was retrieved from the `United States Geological Survey`_ (USGS) on 2020-04-30. Coastal contours were retrieved from `OpenSteetMap`_: Copyright © OpenStreetMap contributors / `Open Database License 1.0`_.

.. _hypocenters: https://en.wikipedia.org/wiki/Hypocenter
.. _United States Geological Survey: https://earthquake.usgs.gov/
.. _OpenSteetMap: https://www.openstreetmap.org/
.. _Open Database License 1.0: https://opendatacommons.org/licenses/odbl/1-0/

Asteroid Discovery 1980-2020
----------------------------

.. youtube:: i9DtIk-IAKs

This video is inspired by (and essentially a remake of) `Asteroid Discovery From 1980 - 2010`_ by `Scott Manley`_. The video shows the discovery of asteroids over time. "New" asteroids are highlighted for one second and then added to the background density plot. The inner four planets - Mercury, Venus, Earth and Mars - are always visible. The gas giant Jupiter can occasionally be seen moving through the edges of the frame. `Orbital elements`_ were retrieved from the `Minor Planet Center`_ on 2020-09-14. `Ephemerides`_ were computed from the orbital elements using `poliastro`_.

.. _Asteroid Discovery From 1980 - 2010: https://www.youtube.com/watch?v=S_d-gs0WoUw
.. _Scott Manley: https://twitter.com/DJSnM
.. _Ephemerides: https://en.wikipedia.org/wiki/Ephemeris
.. _Orbital elements: https://en.wikipedia.org/wiki/Orbital_elements
.. _Minor Planet Center: https://www.minorplanetcenter.net/data
.. _poliastro: https://github.com/poliastro/poliastro

Density Wave Theory
-------------------

.. youtube:: arWvq_9_0ak

The `density wave theory`_ by Lin & Shu (1964) provides an explanation for stable arms of spiral galaxies. It is also an interesting and widely used theme for visualizations. The above example contains 10 million stars and highlights the secret location of `Magrathea`_.

.. _density wave theory: https://en.wikipedia.org/wiki/Density_wave_theory
.. _Magrathea: https://hitchhikers.fandom.com/wiki/Magrathea
